# package_name

Description. 
The package package_name is used to:
	Processing:
		- Histogram matching
		- Structural similarity
		- Resize image
	Utils:
		- Read image
		- Save image
		- Plot image
		- Plot results
		- Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install image_process_DIO
```

## Usage

```python
from image_process_dio.utils import io, plot
from image_process_dio.process import combination, transformation

file1_name.my_function()
```

## Author
Glaucio Drumond

## License
[MIT](https://choosealicense.com/licenses/mit/)